# Summary

- _Why is this change needed?_
- _What does it do at a high level?_
- _Link to relevant specs/issues if applicable._

# Testing

- \[ \] `make pre-commit`
- \[ \] `make test`
- \[ \] Other: <!-- e.g., manual verification, targeted command -->

# Changelog & Docs

- \[ \] Added or updated entry under `[Unreleased]` in `CHANGELOG.md`
- \[ \] Documentation updated (README, TECHNICAL_SPEC, etc.)

# Screenshots or CLI Output (if applicable)

<!-- Drop visuals for UI changes or paste CLI output; remove section if not needed. -->

# Checklist

- \[ \] Small, orthogonal commits
- \[ \] Branch up to date with base
- \[ \] CI passes after push
